@@ -21,11 +21,11 @@
 #       will be removed from Python at some later time. See:
 # https://docs.python.org/3/whatsnew/3.0.html#pep-3101-a-new-approach-to-string-formatting
 
-# Standard library imports
+###### Standard library imports ######
 from datetime import datetime, timedelta
 import sys			# required for .stdout.write()
 
-# Local application imports
+###### Local application imports ######
 from sfalmanac.lib import config as config
 if config.MULTIpr:      # in multi-processing mode ...
     # ------------------------------------------------------
@@ -50,9 +50,9 @@ else:
 UpperLists = [[], []]    # moon GHA per hour for 2 days
 LowerLists = [[], []]    # moon colong GHA per hour for 2 days
 
-#----------------------
-#   internal methods
-#----------------------
+#------------------------
+#   internal functions
+#------------------------
 
 def fmtdate(d):
     if config.pgsz == 'Letter': return d.strftime("%m/%d/%Y")
@@ -466,7 +466,7 @@ def pages(first_day, dtp, ts, spad):
 #   external entry point
 #--------------------------
 
-def maketables(first_day, dtp, ts, spad, df180, df360):
+def makeEVtables(first_day, dtp, ts, spad, df180, df360):
     # dtp = 0 if for entire year; = -1 if for entire month; else days to print
 
     # make tables starting from first_day
@@ -534,15 +534,17 @@ def maketables(first_day, dtp, ts, spad, df180, df360):
 % for the title page only...
 \newgeometry{{nomarginpar, top={}, bottom={}, left={}, right={}}}'''.format(tm1,bm1,lm1,rm1)
 
+    alm = alm + r'''
+    \begin{titlepage}
+    \begin{center}
+    \textsc{\Large Generated using Skyfield}\\
+    \large http://rhodesmill.org/skyfield/\\[0.7cm]'''
+
     if config.dockerized:   # DOCKER ONLY
         df180 = "../A4chart0-180_P.pdf"
         df360 = "../A4chart180-360_P.pdf"
 
     alm = alm + r'''
-    \begin{{titlepage}}
-    \begin{{center}}
-    \textsc{{\Large Generated using Skyfield}}\\
-    \large http://rhodesmill.org/skyfield/\\[0.7cm]
     % TRIM values: left bottom right top
     \includegraphics[clip, trim=12mm 20cm 12mm 21mm, width=0.92\textwidth]{{{}}}\\[0.3cm]
     \includegraphics[clip, trim=12mm 20cm 12mm 21mm, width=0.92\textwidth]{{{}}}\\'''.format(df180,df360)
