@@ -41,14 +41,14 @@
 #       The following code now uses the 'tabular' table style without any
 #       column width specifiers - thus table widths vary slightly from page to page.
 
-# Standard library imports
+###### Standard library imports ######
 from datetime import datetime, timedelta
 import sys			# required for .stdout.write()
 from math import cos as cos
 from math import copysign as copysign
 from math import pi as pi
 
-# Local application imports
+###### Local application imports ######
 from sfalmanac.lib.alma_ephem import magnitudes
 from sfalmanac.lib import config as config
 if config.MULTIpr:  # in multi-processing mode ...
@@ -67,9 +67,9 @@ else:
 UpperLists = [[], [], []]    # moon GHA per hour for 3 days
 LowerLists = [[], [], []]    # moon colong GHA per hour for 3 days
 
-#----------------------
-#   internal methods
-#----------------------
+#------------------------
+#   internal functions
+#------------------------
 
 def fmtdate(d):
     if config.pgsz == 'Letter': return d.strftime("%m/%d/%Y")
@@ -1404,15 +1404,17 @@ def almanac(first_day, dtp, ts, spad, df180, df360, dfcm):
 % for the title page only...
 \newgeometry{{nomarginpar, top={}, bottom={}, left={}, right={}}}'''.format(tm1,bm1,lm1,rm1)
 
+    alm = alm + r'''
+    \begin{titlepage}
+    \begin{center}
+    \textsc{\Large Generated using Skyfield}\\
+    \large http://rhodesmill.org/skyfield/\\[0.7cm]'''
+    
     if config.dockerized:   # DOCKER ONLY
         df180 = "../A4chart0-180_P.pdf"
         df360 = "../A4chart180-360_P.pdf"
 
     alm = alm + r'''
-    \begin{{titlepage}}
-    \begin{{center}}
-    \textsc{{\Large Generated using Skyfield}}\\
-    \large http://rhodesmill.org/skyfield/\\[0.7cm]
     % TRIM values: left bottom right top
     \includegraphics[clip, trim=12mm 20cm 12mm 21mm, width=0.92\textwidth]{{{}}}\\[0.3cm]
     \includegraphics[clip, trim=12mm 20cm 12mm 21mm, width=0.92\textwidth]{{{}}}\\'''.format(df180,df360)
