@@ -22,17 +22,17 @@
 #       will be removed from Python at some later time. See:
 # https://docs.python.org/3/whatsnew/3.0.html#pep-3101-a-new-approach-to-string-formatting
 
-# Standard library imports
+###### Standard library imports ######
 from datetime import datetime, timedelta
 from math import copysign as copysign
 
-# Local application imports
+###### Local application imports ######
 from sfalmanac.lib import config as config
 from sfalmanac.lib import alma_skyfield as alma_skyfield
 
-#----------------------
-#   internal methods
-#----------------------
+#------------------------
+#   internal functions
+#------------------------
 
 def declCompare(prev_deg, curr_deg, next_deg, hr):
     # for Declinations only...
@@ -430,14 +430,16 @@ def sunalmanac(first_day, dtp, dfra):
 % for the title page and page 2 only...
 \newgeometry{nomarginpar, top=5mm, bottom=13mm, left=20mm, right=14mm}'''
 
+    alm = alm + r'''
+    \begin{titlepage}\vspace*{1.5cm}
+    \begin{center}
+    \textsc{\Large Generated using Skyfield}\\
+    \large http://rhodesmill.org/skyfield/\\[1.5cm]'''
+
     if config.dockerized:   # DOCKER ONLY
         dfra = "../Ra"
 
     alm = alm + r'''
-    \begin{{titlepage}}\vspace*{{1.5cm}}
-    \begin{{center}}
-    \textsc{{\Large Generated using Skyfield}}\\
-    \large http://rhodesmill.org/skyfield/\\[1.5cm]
     \includegraphics[width=0.4\textwidth]{{{}}}\\[1cm]
     \textsc{{\huge The Nautical Almanac for the Sun}}\\[0.7cm]'''.format(dfra)
 
